Flask-SSE
=========

A Flask extension for HTML5 `server-sent events`_ support, powered by Redis_.

.. toctree::
   :maxdepth: 2

   quickstart
   config
   advanced
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _server-sent events: https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events
.. _Redis: http://www.redis.io/

